A set of small utility scripts of MRI processing.

Currently, this only contains the script ``modelCorr``, a simple command line
tool to show correlations of fMRI Model Design. At present
(version 0.0.1) this really doesn't do more than output a static png and design
matrix, though more features are planned including calculation of the model's
variance inflation factor (VIF) for contrasts of interest and possibly some
python ports of model optimization. But hey, release [very] early and often.
